class FormRunnerError(Exception):
    pass


class FormRunnerModelAdminNotFound(Exception):
    pass


class FormRunnerImproperlyConfigured(Exception):
    pass


class FormRunnerRegisterError(Exception):
    pass
